[][src]Struct style::properties::ComputedValues

pub struct ComputedValues {
    inner: ComputedValuesInner,
    pseudo: Option<PseudoElement>,
}

The struct that Servo uses to represent computed values.

This struct contains an immutable atomically-reference-counted pointer to every kind of style struct.

When needed, the structs may be copied in order to get mutated.

Fields

inner: ComputedValuesInner

The actual computed values

In Gecko the outer ComputedValues is actually a ComputedStyle, whereas ComputedValuesInner is the core set of computed values.

We maintain this distinction in servo to reduce the amount of special casing.

pseudo: Option<PseudoElement>

The pseudo-element that we're using.

Implementations

impl ComputedValues[src]

pub fn pseudo(&self) -> Option<&PseudoElement>[src]

Returns the pseudo-element that this style represents.

pub fn is_pseudo_style(&self) -> bool[src]

Returns true if this is the style for a pseudo-element.

pub fn is_display_contents(&self) -> bool[src]

Returns whether this style's display value is equal to contents.

pub fn rules(&self) -> &StrongRuleNode[src]

Gets a reference to the rule node. Panic if no rule node exists.

pub fn visited_style(&self) -> Option<&ComputedValues>[src]

Returns the visited style, if any.

pub fn visited_rules(&self) -> Option<&StrongRuleNode>[src]

Returns the visited rules, if applicable.

pub fn custom_properties(&self) -> Option<&Arc<CustomPropertiesMap>>[src]

Gets a reference to the custom properties map (if one exists).

pub fn clone_align_content(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_align_items(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_align_self(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_aspect_ratio(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_backface_visibility(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_collapse(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_image_repeat(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_box_sizing(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_caption_side(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_clear(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_column_count(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_direction(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_display(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_empty_cells(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_flex_direction(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_flex_wrap(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_float(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_font_stretch(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_font_style(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_font_variant_caps(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_font_weight(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_image_rendering(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_justify_content(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_list_style_position(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_list_style_type(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_mix_blend_mode(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_opacity(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_order(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_outline_style(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_overflow_wrap(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_pointer_events(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_position(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone__servo_overflow_clip_box(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone__servo_top_layer(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_table_layout(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_text_align(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_text_decoration_line(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_text_justify(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_text_rendering(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_text_transform(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_transform_style(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_unicode_bidi(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_visibility(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_white_space(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_word_break(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_writing_mode(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_z_index(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_flex_grow(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_flex_shrink(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_overflow_block(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_overflow_inline(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_overflow_x(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_overflow_y(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_block_end_style(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_block_start_style(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_bottom_style(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_inline_end_style(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_inline_start_style(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_left_style(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_right_style(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_top_style(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_animation_delay(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_animation_direction(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_animation_duration(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_animation_fill_mode(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_animation_iteration_count(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_animation_name(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_animation_play_state(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_animation_timing_function(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_background_attachment(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_background_clip(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_background_image(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_background_origin(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_background_position_x(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_background_position_y(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_background_repeat(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_background_size(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_image_outset(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_image_slice(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_image_source(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_image_width(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_spacing(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_box_shadow(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_clip(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_color(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_column_gap(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_column_width(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_content(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_counter_increment(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_counter_reset(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_cursor(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_filter(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_flex_basis(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_font_family(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_font_size(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_letter_spacing(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_line_height(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_list_style_image(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_outline_offset(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_perspective(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_perspective_origin(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_quotes(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_rotate(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_scale(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_text_indent(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_text_overflow(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_text_shadow(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_transform(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_transform_origin(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_transition_delay(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_transition_duration(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_transition_property(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_transition_timing_function(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_translate(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_vertical_align(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_word_spacing(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_max_block_size(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_max_height(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_max_inline_size(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_max_width(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_bottom_left_radius(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_bottom_right_radius(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_end_end_radius(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_end_start_radius(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_start_end_radius(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_start_start_radius(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_top_left_radius(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_top_right_radius(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_padding_block_end(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_padding_block_start(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_padding_bottom(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_padding_inline_end(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_padding_inline_start(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_padding_left(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_padding_right(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_padding_top(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_block_size(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_height(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_inline_size(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_min_block_size(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_min_height(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_min_inline_size(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_min_width(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_width(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_block_end_width(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_block_start_width(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_bottom_width(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_inline_end_width(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_inline_start_width(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_left_width(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_right_width(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_top_width(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_outline_width(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_background_color(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_block_end_color(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_block_start_color(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_bottom_color(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_inline_end_color(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_inline_start_color(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_left_color(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_right_color(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_border_top_color(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_outline_color(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_bottom(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_inset_block_end(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_inset_block_start(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_inset_inline_end(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_inset_inline_start(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_left(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_margin_block_end(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_margin_block_start(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_margin_bottom(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_margin_inline_end(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_margin_inline_start(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_margin_left(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_margin_right(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_margin_top(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_right(&self) -> T[src]

Gets the computed value of a given property.

pub fn clone_top(&self) -> T[src]

Gets the computed value of a given property.

pub fn get_longhand_property_value<W>(
    &self,
    property_id: LonghandId,
    dest: &mut CssWriter<W>
) -> Result where
    W: Write
[src]

Writes the value of the given longhand as a string in dest.

Note that the value will usually be the computed value, except for colors, where it's resolved.

pub fn resolve_color(&self, color: Color) -> RGBA[src]

Resolves the currentColor keyword.

Any color value from computed values (except for the 'color' property itself) should go through this method.

Usage example: let top_color = style.resolve_color(style.get_border().clone_border_top_color());

pub fn transition_properties<'a>(&'a self) -> TransitionPropertyIterator<'a>[src]

Create a TransitionPropertyIterator for this styles transition properties.

impl ComputedValues[src]

pub fn new(
    pseudo: Option<&PseudoElement>,
    custom_properties: Option<Arc<CustomPropertiesMap>>,
    writing_mode: WritingMode,
    flags: ComputedValueFlags,
    rules: Option<StrongRuleNode>,
    visited_style: Option<Arc<ComputedValues>>,
    background: Arc<Background>,
    border: Arc<Border>,
    box_: Arc<Box>,
    column: Arc<Column>,
    counters: Arc<Counters>,
    effects: Arc<Effects>,
    font: Arc<Font>,
    inherited_box: Arc<InheritedBox>,
    inherited_table: Arc<InheritedTable>,
    inherited_text: Arc<InheritedText>,
    inherited_ui: Arc<InheritedUI>,
    list: Arc<List>,
    margin: Arc<Margin>,
    outline: Arc<Outline>,
    padding: Arc<Padding>,
    position: Arc<Position>,
    table: Arc<Table>,
    text: Arc<Text>
) -> Arc<Self>
[src]

Create a new refcounted ComputedValues

pub fn initial_values() -> &'static Self[src]

Get the initial computed values.

pub fn computed_value_to_string(
    &self,
    property: PropertyDeclarationId
) -> String
[src]

Serializes the computed value of this property as a string.

Methods from Deref<Target = ComputedValuesInner>

pub fn clone_background(&self) -> Arc<Background>[src]

Clone the Background struct.

pub fn get_background(&self) -> &Background[src]

Get a immutable reference to the Background struct.

pub fn background_arc(&self) -> &Arc<Background>[src]

Gets an immutable reference to the refcounted value that wraps Background.

pub fn mutate_background(&mut self) -> &mut Background[src]

Get a mutable reference to the Background struct.

pub fn clone_border(&self) -> Arc<Border>[src]

Clone the Border struct.

pub fn get_border(&self) -> &Border[src]

Get a immutable reference to the Border struct.

pub fn border_arc(&self) -> &Arc<Border>[src]

Gets an immutable reference to the refcounted value that wraps Border.

pub fn mutate_border(&mut self) -> &mut Border[src]

Get a mutable reference to the Border struct.

pub fn clone_box(&self) -> Arc<Box>[src]

Clone the Box struct.

pub fn get_box(&self) -> &Box[src]

Get a immutable reference to the Box struct.

pub fn box_arc(&self) -> &Arc<Box>[src]

Gets an immutable reference to the refcounted value that wraps Box.

pub fn mutate_box(&mut self) -> &mut Box[src]

Get a mutable reference to the Box struct.

pub fn clone_column(&self) -> Arc<Column>[src]

Clone the Column struct.

pub fn get_column(&self) -> &Column[src]

Get a immutable reference to the Column struct.

pub fn column_arc(&self) -> &Arc<Column>[src]

Gets an immutable reference to the refcounted value that wraps Column.

pub fn mutate_column(&mut self) -> &mut Column[src]

Get a mutable reference to the Column struct.

pub fn clone_counters(&self) -> Arc<Counters>[src]

Clone the Counters struct.

pub fn get_counters(&self) -> &Counters[src]

Get a immutable reference to the Counters struct.

pub fn counters_arc(&self) -> &Arc<Counters>[src]

Gets an immutable reference to the refcounted value that wraps Counters.

pub fn mutate_counters(&mut self) -> &mut Counters[src]

Get a mutable reference to the Counters struct.

pub fn clone_effects(&self) -> Arc<Effects>[src]

Clone the Effects struct.

pub fn get_effects(&self) -> &Effects[src]

Get a immutable reference to the Effects struct.

pub fn effects_arc(&self) -> &Arc<Effects>[src]

Gets an immutable reference to the refcounted value that wraps Effects.

pub fn mutate_effects(&mut self) -> &mut Effects[src]

Get a mutable reference to the Effects struct.

pub fn clone_font(&self) -> Arc<Font>[src]

Clone the Font struct.

pub fn get_font(&self) -> &Font[src]

Get a immutable reference to the Font struct.

pub fn font_arc(&self) -> &Arc<Font>[src]

Gets an immutable reference to the refcounted value that wraps Font.

pub fn mutate_font(&mut self) -> &mut Font[src]

Get a mutable reference to the Font struct.

pub fn clone_inherited_box(&self) -> Arc<InheritedBox>[src]

Clone the InheritedBox struct.

pub fn get_inherited_box(&self) -> &InheritedBox[src]

Get a immutable reference to the InheritedBox struct.

pub fn inherited_box_arc(&self) -> &Arc<InheritedBox>[src]

Gets an immutable reference to the refcounted value that wraps InheritedBox.

pub fn mutate_inherited_box(&mut self) -> &mut InheritedBox[src]

Get a mutable reference to the InheritedBox struct.

pub fn clone_inherited_table(&self) -> Arc<InheritedTable>[src]

Clone the InheritedTable struct.

pub fn get_inherited_table(&self) -> &InheritedTable[src]

Get a immutable reference to the InheritedTable struct.

pub fn inherited_table_arc(&self) -> &Arc<InheritedTable>[src]

Gets an immutable reference to the refcounted value that wraps InheritedTable.

pub fn mutate_inherited_table(&mut self) -> &mut InheritedTable[src]

Get a mutable reference to the InheritedTable struct.

pub fn clone_inherited_text(&self) -> Arc<InheritedText>[src]

Clone the InheritedText struct.

pub fn get_inherited_text(&self) -> &InheritedText[src]

Get a immutable reference to the InheritedText struct.

pub fn inherited_text_arc(&self) -> &Arc<InheritedText>[src]

Gets an immutable reference to the refcounted value that wraps InheritedText.

pub fn mutate_inherited_text(&mut self) -> &mut InheritedText[src]

Get a mutable reference to the InheritedText struct.

pub fn clone_inherited_ui(&self) -> Arc<InheritedUI>[src]

Clone the InheritedUI struct.

pub fn get_inherited_ui(&self) -> &InheritedUI[src]

Get a immutable reference to the InheritedUI struct.

pub fn inherited_ui_arc(&self) -> &Arc<InheritedUI>[src]

Gets an immutable reference to the refcounted value that wraps InheritedUI.

pub fn mutate_inherited_ui(&mut self) -> &mut InheritedUI[src]

Get a mutable reference to the InheritedUI struct.

pub fn clone_list(&self) -> Arc<List>[src]

Clone the List struct.

pub fn get_list(&self) -> &List[src]

Get a immutable reference to the List struct.

pub fn list_arc(&self) -> &Arc<List>[src]

Gets an immutable reference to the refcounted value that wraps List.

pub fn mutate_list(&mut self) -> &mut List[src]

Get a mutable reference to the List struct.

pub fn clone_margin(&self) -> Arc<Margin>[src]

Clone the Margin struct.

pub fn get_margin(&self) -> &Margin[src]

Get a immutable reference to the Margin struct.

pub fn margin_arc(&self) -> &Arc<Margin>[src]

Gets an immutable reference to the refcounted value that wraps Margin.

pub fn mutate_margin(&mut self) -> &mut Margin[src]

Get a mutable reference to the Margin struct.

pub fn clone_outline(&self) -> Arc<Outline>[src]

Clone the Outline struct.

pub fn get_outline(&self) -> &Outline[src]

Get a immutable reference to the Outline struct.

pub fn outline_arc(&self) -> &Arc<Outline>[src]

Gets an immutable reference to the refcounted value that wraps Outline.

pub fn mutate_outline(&mut self) -> &mut Outline[src]

Get a mutable reference to the Outline struct.

pub fn clone_padding(&self) -> Arc<Padding>[src]

Clone the Padding struct.

pub fn get_padding(&self) -> &Padding[src]

Get a immutable reference to the Padding struct.

pub fn padding_arc(&self) -> &Arc<Padding>[src]

Gets an immutable reference to the refcounted value that wraps Padding.

pub fn mutate_padding(&mut self) -> &mut Padding[src]

Get a mutable reference to the Padding struct.

pub fn clone_position(&self) -> Arc<Position>[src]

Clone the Position struct.

pub fn get_position(&self) -> &Position[src]

Get a immutable reference to the Position struct.

pub fn position_arc(&self) -> &Arc<Position>[src]

Gets an immutable reference to the refcounted value that wraps Position.

pub fn mutate_position(&mut self) -> &mut Position[src]

Get a mutable reference to the Position struct.

pub fn clone_table(&self) -> Arc<Table>[src]

Clone the Table struct.

pub fn get_table(&self) -> &Table[src]

Get a immutable reference to the Table struct.

pub fn table_arc(&self) -> &Arc<Table>[src]

Gets an immutable reference to the refcounted value that wraps Table.

pub fn mutate_table(&mut self) -> &mut Table[src]

Get a mutable reference to the Table struct.

pub fn clone_text(&self) -> Arc<Text>[src]

Clone the Text struct.

pub fn get_text(&self) -> &Text[src]

Get a immutable reference to the Text struct.

pub fn text_arc(&self) -> &Arc<Text>[src]

Gets an immutable reference to the refcounted value that wraps Text.

pub fn mutate_text(&mut self) -> &mut Text[src]

Get a mutable reference to the Text struct.

pub fn rules(&self) -> &StrongRuleNode[src]

Gets a reference to the rule node. Panic if no rule node exists.

pub fn ineffective_content_property(&self) -> bool[src]

Returns whether the "content" property for the given style is completely ineffective, and would yield an empty ::before or ::after pseudo-element.

pub fn can_be_fragmented(&self) -> bool[src]

Whether the current style or any of its ancestors is multicolumn.

pub fn is_multicol(&self) -> bool[src]

Whether the current style is multicolumn.

pub fn content_inline_size(&self) -> &Size[src]

Get the logical computed inline size.

pub fn content_block_size(&self) -> &Size[src]

Get the logical computed block size.

pub fn min_inline_size(&self) -> &Size[src]

Get the logical computed min inline size.

pub fn min_block_size(&self) -> &Size[src]

Get the logical computed min block size.

pub fn max_inline_size(&self) -> &MaxSize[src]

Get the logical computed max inline size.

pub fn max_block_size(&self) -> &MaxSize[src]

Get the logical computed max block size.

pub fn logical_padding(&self) -> LogicalMargin<&LengthPercentage>[src]

Get the logical computed padding for this writing mode.

pub fn border_width_for_writing_mode(
    &self,
    writing_mode: WritingMode
) -> LogicalMargin<Au>
[src]

Get the logical border width

pub fn logical_border_width(&self) -> LogicalMargin<Au>[src]

Gets the logical computed border widths for this style.

pub fn logical_margin(&self) -> LogicalMargin<&LengthPercentageOrAuto>[src]

Gets the logical computed margin from this style.

pub fn logical_position(&self) -> LogicalMargin<&LengthPercentageOrAuto>[src]

Gets the logical position from this style.

pub fn overrides_transform_style(&self) -> bool[src]

Return true if the effects force the transform style to be Flat

pub fn get_used_transform_style(&self) -> T[src]

pub fn transform_requires_layer(&self) -> bool[src]

Whether given this transform value, the compositor would require a layer.