IdSet

Struct IdSet 

pub struct IdSet<Id: IndexedId, const W: usize> {
    storage: [u32; W],
    _phantom: PhantomData<Id>,
}
A set of ids indexed in a bitfield. W is the number of u32 chunks needed to store Id::COUNT bits, and is filled in by the type aliases above.

TODO(emilio): It’d be nice for the const parameter to be COUNT (or even not be there and pull from Id::COUNT), but that can’t be done in stable rust yet, see: https://github.com/rust-lang/rust/issues/76560

Fields

storage: [u32; W]_phantom: PhantomData<Id>

Implementations

Source

impl IdSet<LonghandId, { (property_counts::LONGHANDS - 1 + 32) / 32 }>

pub(super) fn reset() -> &'static Self

The set of non-inherited longhands.

pub(super) fn discrete_animatable() -> &'static Self

pub(super) fn logical() -> &'static Self

pub(super) fn ignored_when_colors_disabled() -> &'static Self

Returns the set of longhands that are ignored when document colors are disabled.

pub(super) fn visited_dependent() -> &'static Self

Only a few properties are allowed to depend on the visited state of links. When cascading visited styles, we can save time by only processing these properties.

pub(super) fn prioritary_properties() -> &'static Self

pub(super) fn late_group_only_inherited() -> &'static Self

pub(super) fn late_group() -> &'static Self

pub fn margin_properties() -> &'static Self

Returns the set of margin properties, for the purposes of

use counters / warnings.

pub fn border_background_properties() -> &'static Self

Returns the set of border properties for the purpose of disabling native appearance.

pub fn zoom_dependent() -> &'static Self

Returns properties that are zoom dependent (basically, that contain lengths).

pub fn zoom_dependent_inherited_properties() -> &'static Self

Note that it’s different from zoom_dependent(), as this only includes inherited, physical properties.

Source

impl<Id: IndexedId, const W: usize> IdSet<Id, W>

pub fn new() -> Self

Creates an empty IdSet.

pub(crate) const fn from_storage(storage: [u32; W]) -> Self

Creates a set from its raw bitfield storage.

pub fn insert(&mut self, id: Id)

Insert an id in the set.

pub fn remove(&mut self, id: Id)

Remove the given id from the set.

pub fn contains(&self, id: Id) -> bool

Return whether the given id is in the set.

pub fn iter(&self) -> IdSetIterator<'_, Id>

Iterate over the current id set.

pub fn contains_all(&self, other: &Self) -> bool

Returns whether this set contains at least every id that other also contains.

pub fn contains_any(&self, other: &Self) -> bool

Returns whether this set contains any id that other also contains.

pub fn remove_all(&mut self, other: &Self)

Remove all the given ids from the set.

pub fn clear(&mut self)

Clear all bits

pub fn is_empty(&self) -> bool

Returns whether the set is empty.

Source

impl IdSet<LonghandId, { (property_counts::LONGHANDS - 1 + 32) / 32 }>

pub fn contains_any_reset(&self) -> bool

Return whether this set contains any reset longhand.